@@ -6,6 +6,7 @@
 #' @export
 
 lint_bib <- function(bib_file, outfile = bib_file, leading_spaces = 2L){
+  
   stopifnot(length(bib_file) == 1L, grepl("\\.bib$", bib_file, perl = TRUE))
 
   bib <- readLines(bib_file, encoding = "UTF-8", warn = FALSE)
@@ -17,20 +18,34 @@ lint_bib <- function(bib_file, outfile = bib_file, leading_spaces = 2L){
 
   out <- bib
 
-  # Vectorized gsub:
-  for (line in seq_along(bib)){
+  # Vectorized gsub. Required because spaces_required is 
+  # different every line.
+  for (line in seq_along(bib)) {
     # Replace every field line with
     # two spaces + field name + spaces required for widest field + space
-    if (is_field[line]){
-    spaces_req <- widest_field - field_width[line]
-    out[line] <-
-      gsub("^\\s*(\\w+)\\s*[=]\\s*\\{",
-           paste0(paste0(rep(" ", leading_spaces), collapse = ""),
-                  "\\L\\1",
-                  paste0(rep(" ", spaces_req), collapse = ""),
-                  " = {"),
-           bib[line],
-           perl = TRUE)
+    if (is_field[line]) {
+      spaces_req <- widest_field - field_width[line]
+      if (getRversion() > "3.4.0") {
+        
+        
+        out[line] <-
+          gsub("^\\s*(\\w+)\\s*[=]\\s*\\{", 
+               paste0(paste0(rep(" ", leading_spaces), collapse = ""),
+                      "\\1",
+                      paste0(rep(" ", spaces_req), collapse = ""),
+                      " = {"),
+               bib[line],
+               perl = TRUE)
+      } else {
+        out[line] <-
+          gsub("^\\s*(\\w+)\\s*[=]\\s*\\{",
+               paste0(paste0(rep(" ", leading_spaces), collapse = ""),
+                      "\\L\\1",
+                      paste0(rep(" ", spaces_req), collapse = ""),
+                      " = {"),
+               bib[line],
+               perl = TRUE)
+      }
     }
   }
   
